@@ -72,10 +72,10 @@ class CrudView(View):
         self.data = crud.post(**body, **kwargs)
         return self._respond()
 
-    def bulk_post(self, request, **kwargs):
+    def bulk_post(self, request, filters, **kwargs):
         crud = self.CRUD_CLASS()
         body = unjsonize(request.body.decode())
-        self.data = crud.bulk_post(data=body,**kwargs)
+        self.data = crud.bulk_post(data=body, **filters, **kwargs)
         return self._respond()
 
     def put(self, request, filters, **kwargs):
